@@ -12,7 +12,5 @@ export const getVpnIp = async () => {
     ipProc.init(null);
 
     let [ipOutput] = await ipProc.communicate_utf8_async(null, null);
-    [ipOutput] = ipOutput.match(/(?<=inet )\d{1,3}(\.\d{1,3}){3}/);
-
-    return ipOutput;
+    return (ipOutput.match(/(?<=inet )\d{1,3}(\.\d{1,3}){3}/) || [])[0];
 };
